@@ -1,4 +1,4 @@
-# $Id: filter_innd.pl,v 1.5 2005/04/15 14:07:11 jochen Exp $
+# $Id: filter_innd.pl,v 1.6 2010/01/05 12:01:13 jochen Exp $
 # Copyright (c) 2004-2005 Jochen Striepe <t-prot@tolot.escape.de>
 #
 # This file is provided as an example how t-prot can be used for
@@ -51,7 +51,7 @@ sub filter_art {
 		print OUT $foo;
 		close OUT;
 
-		open(IN, "/usr/bin/t-prot -m -t -p --body --check -i $f|")
+		open(IN, "/usr/bin/t-prot -m -t -p --body --check=ratio -i $f|")
 			|| goto FINISH;
 		$rval = <IN>;
 		close IN;
